pub struct TriggerSystem { /* private fields */ }Expand description
The trigger system maintains an ordered list of triggers.
Implementations
Sourceimpl TriggerSystem
impl TriggerSystem
Sourcepub fn write_to(&self, output: impl Write, version: f64) -> Result<()>
pub fn write_to(&self, output: impl Write, version: f64) -> Result<()>
Write the trigger system to an output stream with the given system version.
Sourcepub fn num_triggers(&self) -> u32
pub fn num_triggers(&self) -> u32
Get the number of triggers in the trigger system.
Sourcepub fn triggers_unordered_mut(&mut self) -> impl Iterator<Item = &mut Trigger>
pub fn triggers_unordered_mut(&mut self) -> impl Iterator<Item = &mut Trigger>
Iterate over all triggers, mutably and unordered.